summaryrefslogtreecommitdiffstats
path: root/khtml/dom/css_extensions.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-21 14:22:15 -0600
committerTimothy Pearson <[email protected]>2011-12-21 14:22:15 -0600
commit1180237ab336226ad932d767a6cb56208314988f (patch)
tree0a29b4d5d237f445dc87cb65b00d604ad4aa686d /khtml/dom/css_extensions.h
parenta51cd9949c4e6c726a84a61de3cfadd30cefb5c7 (diff)
downloadtdelibs-1180237ab336226ad932d767a6cb56208314988f.tar.gz
tdelibs-1180237ab336226ad932d767a6cb56208314988f.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'khtml/dom/css_extensions.h')
-rw-r--r--khtml/dom/css_extensions.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/dom/css_extensions.h b/khtml/dom/css_extensions.h
index bda2cfbbc..e93cb7d21 100644
--- a/khtml/dom/css_extensions.h
+++ b/khtml/dom/css_extensions.h
@@ -2516,13 +2516,13 @@ public:
/**
* See the <a
* href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-tqunicode-bidi">
* tqunicode-bidi property definition </a> in CSS2.
*
*/
- DOM::DOMString tqunicodeBidi() const;
+ DOM::DOMString unicodeBidi() const;
/**
- * see tqunicodeBidi
+ * see unicodeBidi
*/
void setUnicodeBidi( const DOM::DOMString & );
@@ -2516,13 +2516,13 @@ public:
* See the <a
* href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-tqunicode-bidi">
- * tqunicode-bidi property definition </a> in CSS2.
+ * unicode-bidi property definition </a> in CSS2.
*
*/